@@ -4,61 +4,52 @@
 <context>
     <name>SelectWnd</name>
     <message>
-        <location filename="../ui/selectwnd.ui" line="14"/>
+        <location filename="../selectwnd.ui" line="14"/>
         <source>LXQt Mouse Theme Configuration</source>
-        <translation>اعداد شكل فأرة سطح ريزر</translation>
+        <translation>ضبط لكسكيوت لسمة الفأرة</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="20"/>
+        <location filename="../selectwnd.ui" line="20"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>اختر سكل المؤشِّر الذي تريد استخدامه (مرر المؤشِّر متخطيَّاً لمعاينته).
-&lt;b&gt;يجب إعادة تشغيل جلسة سطح ريزر بعد هذا التَّغيير&lt;/b&gt;</translation>
+        <translation>اختر سمة المؤشّر لاستخدامها (ضع المؤشّر على المعاينة لاختباره). &lt;b&gt;يجب إعادة تشغيل جلسة لكسكيوت بعد تغيير هذا&lt;/b&gt;:</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="81"/>
+        <location filename="../selectwnd.ui" line="81"/>
         <source>&amp;Install New Theme...</source>
-        <translation>تث&amp;بيت واجهةٍ شكليَّةٍ جديدةٍ...</translation>
+        <translation>&amp;ثبّت سمة جديدة...</translation>
     </message>
     <message>
-        <source>&amp;Set Theme</source>
-        <translation type="vanished">ت^عيين الواجهة الشَّكليَّة</translation>
-    </message>
-    <message>
-        <location filename="../ui/selectwnd.ui" line="88"/>
+        <location filename="../selectwnd.ui" line="88"/>
         <source>&amp;Remove Theme</source>
-        <translation>إ&amp;زالة الواجهة الشَّكليَّة</translation>
+        <translation>أ&amp;زِل السمة</translation>
     </message>
     <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">إ&amp;غلاق</translation>
-    </message>
-    <message>
-        <location filename="../selectwnd.cpp" line="208"/>
+        <location filename="../selectwnd.cpp" line="212"/>
         <source>XCurTheme error</source>
-        <translation>خطأٌ في الواجهة الشَّكليَّة للمؤشر الرسوميّ</translation>
+        <translation>خطأ XCurTheme</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="209"/>
+        <location filename="../selectwnd.cpp" line="213"/>
         <source>You can&apos;t remove active theme!</source>
-        <translation>ﻻ يمكنك إزالة واجهةٍ مفعَّلةٍ</translation>
+        <translation>لا يمكنك إزالة سمة نشطة!</translation>
     </message>
 </context>
 <context>
     <name>WarningLabel</name>
     <message>
-        <location filename="../ui/warninglabel.ui" line="14"/>
+        <location filename="../warninglabel.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>استمارة</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="44"/>
+        <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation type="unfinished"></translation>
+        <translation>تعذر على لكسكيوت العثور على أية سمة أيقونات. ستُستخدم سمة مؤشّرات X11 المبدئية. بحثت لكسكيوت في الأدلة الآتية:</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="54"/>
+        <location filename="../warninglabel.ui" line="54"/>
         <source>Show...</source>
-        <translation type="unfinished"></translation>
+        <translation>اعرض...</translation>
     </message>
 </context>
 <context>
