@@ -4,60 +4,52 @@
 <context>
     <name>SelectWnd</name>
     <message>
-        <location filename="../ui/selectwnd.ui" line="14"/>
+        <location filename="../selectwnd.ui" line="14"/>
         <source>LXQt Mouse Theme Configuration</source>
-        <translation>Nastavení motivu myši</translation>
+        <translation>Nastavení vzhledu ukazatele myši</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="20"/>
+        <location filename="../selectwnd.ui" line="20"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>Vyberte motiv ukazovátka, jejž chcete používat (přejeďte myší nad náhledem kvůli vyzkoušení ukazovátka). &lt;b&gt;Sezení LXQt je potřeba po této změně spustit znovu&lt;/b&gt;:</translation>
+        <translation>Vyberte vzhled ukazatele, který chcete používat (vyzkoušíte najetím myší na náhled). &lt;b&gt;Po provedení změny je třeba restartovat sezení LXQt&lt;/b&gt;:</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="81"/>
+        <location filename="../selectwnd.ui" line="81"/>
         <source>&amp;Install New Theme...</source>
-        <translation>Na&amp;instalovat nový motiv...</translation>
+        <translation>Na&amp;instalovat nový vzhled…</translation>
     </message>
     <message>
-        <source>&amp;Set Theme</source>
-        <translation type="vanished">&amp;Nastavit motiv</translation>
-    </message>
-    <message>
-        <location filename="../ui/selectwnd.ui" line="88"/>
+        <location filename="../selectwnd.ui" line="88"/>
         <source>&amp;Remove Theme</source>
-        <translation>&amp;Odstranit motiv</translation>
+        <translation>Odst&amp;ranit vzhled</translation>
     </message>
     <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;Zavřít</translation>
-    </message>
-    <message>
-        <location filename="../selectwnd.cpp" line="208"/>
+        <location filename="../selectwnd.cpp" line="212"/>
         <source>XCurTheme error</source>
         <translation>Chyba XCurTheme</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="209"/>
+        <location filename="../selectwnd.cpp" line="213"/>
         <source>You can&apos;t remove active theme!</source>
-        <translation>Nemůžete odstranit právě nastavený motiv</translation>
+        <translation>Není možné odstranit právě používaný vzhled!</translation>
     </message>
 </context>
 <context>
     <name>WarningLabel</name>
     <message>
-        <location filename="../ui/warninglabel.ui" line="14"/>
+        <location filename="../warninglabel.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>Formulář</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="44"/>
+        <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt se nepodařilo najít žádný vzhled ukazatele. Bude se používat výchozí vzhled graf. serveru X11. LXQt hledalo v následujících složkách:</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="54"/>
+        <location filename="../warninglabel.ui" line="54"/>
         <source>Show...</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobrazit…</translation>
     </message>
 </context>
 <context>
