@@ -6,38 +6,30 @@
     <message>
         <location filename="../selectwnd.ui" line="14"/>
         <source>LXQt Mouse Theme Configuration</source>
-        <translation>Definições do tema de cursor do LXQt</translation>
+        <translation>Configuração do tema de cursor LXQt</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="20"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>Escolha o tema de cursor a utilizar (passe com o rato para testar). &lt;b&gt;Tem que reiniciar o LXQt a sessão após a alteração&lt;/b&gt;:</translation>
+        <translation>Selecione o tema de cursor a utilizar (passe por cima para pré-visualizar). &lt;b&gt;Tem que reiniciar a sessão LXQt para aplicar as alterações&lt;/b&gt;:</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="81"/>
         <source>&amp;Install New Theme...</source>
         <translation>&amp;Instalar novo tema...</translation>
     </message>
-    <message>
-        <source>&amp;Set Theme</source>
-        <translation type="vanished">&amp;Definir tema</translation>
-    </message>
     <message>
         <location filename="../selectwnd.ui" line="88"/>
         <source>&amp;Remove Theme</source>
         <translation>&amp;Remover tema</translation>
     </message>
     <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">Fe&amp;char</translation>
-    </message>
-    <message>
-        <location filename="../selectwnd.cpp" line="208"/>
+        <location filename="../selectwnd.cpp" line="212"/>
         <source>XCurTheme error</source>
         <translation>Erro XCurTheme</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="209"/>
+        <location filename="../selectwnd.cpp" line="213"/>
         <source>You can&apos;t remove active theme!</source>
         <translation>Não pode remover o tema ativo!</translation>
     </message>
@@ -52,7 +44,7 @@
     <message>
         <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation>O LxQt não encontrou quaisquer temas de cursor. Será utilizado o tema de cursor X11. O LxQt procurou nestes diretórios:</translation>
+        <translation>O LXQt não encontrou um tema de cursor. O tema de cursor padrão X11 será utilizado. O LXQt procurou nos seguintes diretórios:</translation>
     </message>
     <message>
         <location filename="../warninglabel.ui" line="54"/>
