@@ -4,52 +4,52 @@
 <context>
     <name>SelectWnd</name>
     <message>
-        <location filename="../ui/selectwnd.ui" line="14"/>
+        <location filename="../selectwnd.ui" line="14"/>
         <source>LXQt Mouse Theme Configuration</source>
         <translation>Настройка темы курсора LXQt</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="20"/>
+        <location filename="../selectwnd.ui" line="20"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>Выберите тему курсора, которую вы хотите использовать (наведите курсор на область предварительного просмотра для проверки). &lt;b&gt;Сессию LXQt нужно перезапустить после изменений&lt;/b&gt;:</translation>
+        <translation>Выберите тему курсора, которую вы хотите использовать (наведите курсор на область предварительного просмотра для проверки). &lt;b&gt;После изменений сессию LXQt нужно будет перезапустить&lt;/b&gt;:</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="81"/>
+        <location filename="../selectwnd.ui" line="81"/>
         <source>&amp;Install New Theme...</source>
-        <translation>&amp;Установить новую тему…</translation>
+        <translation>&amp;Установить новую тему...</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="88"/>
+        <location filename="../selectwnd.ui" line="88"/>
         <source>&amp;Remove Theme</source>
         <translation>&amp;Удалить тему</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="208"/>
+        <location filename="../selectwnd.cpp" line="212"/>
         <source>XCurTheme error</source>
         <translation>Ошибка XCurTheme</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="209"/>
+        <location filename="../selectwnd.cpp" line="213"/>
         <source>You can&apos;t remove active theme!</source>
-        <translation>Невозможно удалить активную тему!</translation>
+        <translation>Нельзя удалить активную тему!</translation>
     </message>
 </context>
 <context>
     <name>WarningLabel</name>
     <message>
-        <location filename="../ui/warninglabel.ui" line="14"/>
+        <location filename="../warninglabel.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>Форма</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="44"/>
+        <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation>LXQt не смог найти какую-нибудь тему курсора. Будет использована тема X11 по-умолчанию. LXQt искал в следующих папках:</translation>
+        <translation>LXQt не смог найти ни одной темы курсора. Будет использована тема X11 по умолчанию. LXQt искал в следующих папках:</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="54"/>
+        <location filename="../warninglabel.ui" line="54"/>
         <source>Show...</source>
-        <translation>Показать…</translation>
+        <translation>Показать...</translation>
     </message>
 </context>
 <context>
