@@ -4,41 +4,32 @@
 <context>
     <name>SelectWnd</name>
     <message>
-        <location filename="../ui/selectwnd.ui" line="14"/>
+        <location filename="../selectwnd.ui" line="14"/>
         <source>LXQt Mouse Theme Configuration</source>
         <translation>LXQt滑鼠游標主題設定</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="20"/>
+        <location filename="../selectwnd.ui" line="20"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>選擇您喜歡的游標主題 (檢視來回移動來測試游標) 。
-&lt;b&gt;套用改變需要重新啟動LXQt會話&lt;/b&gt;:</translation>
+        <translation>選擇你想使用的游標主題 (來回移動來測試游標). &lt;b&gt;改變後需重新啟動LXQt會話&lt;/b&gt;：</translation>
     </message>
     <message>
-        <location filename="../ui/selectwnd.ui" line="81"/>
+        <location filename="../selectwnd.ui" line="81"/>
         <source>&amp;Install New Theme...</source>
-        <translation>安裝新主題...(&amp;I)</translation>
+        <translation>安裝新主題 (&amp;I)...</translation>
     </message>
     <message>
-        <source>&amp;Set Theme</source>
-        <translation type="vanished">設為主題(&amp;S)</translation>
-    </message>
-    <message>
-        <location filename="../ui/selectwnd.ui" line="88"/>
+        <location filename="../selectwnd.ui" line="88"/>
         <source>&amp;Remove Theme</source>
         <translation>移除主題(&amp;R)</translation>
     </message>
     <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">關閉(&amp;C)</translation>
-    </message>
-    <message>
-        <location filename="../selectwnd.cpp" line="208"/>
+        <location filename="../selectwnd.cpp" line="212"/>
         <source>XCurTheme error</source>
         <translation>XCurTheme錯誤</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="209"/>
+        <location filename="../selectwnd.cpp" line="213"/>
         <source>You can&apos;t remove active theme!</source>
         <translation>您無法移除正在套用的主題!</translation>
     </message>
@@ -46,19 +37,19 @@
 <context>
     <name>WarningLabel</name>
     <message>
-        <location filename="../ui/warninglabel.ui" line="14"/>
+        <location filename="../warninglabel.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>表單</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="44"/>
+        <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt找不到任何游標主題，將改為使用X11預設的游標主題，LXQt在下列目錄中尋找：</translation>
     </message>
     <message>
-        <location filename="../ui/warninglabel.ui" line="54"/>
+        <location filename="../warninglabel.ui" line="54"/>
         <source>Show...</source>
-        <translation type="unfinished"></translation>
+        <translation>顯示...</translation>
     </message>
 </context>
 <context>
