@@ -1,128 +1,141 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ar">
+<context>
+    <name>ConfigOtherToolKits</name>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="144"/>
+        <source>GTK themes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="145"/>
+        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>FontsConfig</name>
     <message>
         <location filename="../fontsconfig.ui" line="23"/>
         <source>Font</source>
-        <translation type="unfinished"></translation>
+        <translation>الخط</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="30"/>
         <source>Default font for user interface</source>
-        <translation type="unfinished"></translation>
+        <translation>خط واجهة المستخدم المبدئي</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="36"/>
         <source>Font name:</source>
-        <translation type="unfinished"></translation>
+        <translation>اسم الخط:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="46"/>
         <source>Style:</source>
-        <translation type="unfinished"></translation>
+        <translation>النمط:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="53"/>
         <source>Point size:</source>
-        <translation type="unfinished"></translation>
+        <translation>حجم النقطة:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="68"/>
         <source>Normal</source>
-        <translation type="unfinished"></translation>
+        <translation>عادي</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="73"/>
         <source>Bold</source>
-        <translation type="unfinished"></translation>
+        <translation>ثخين</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="78"/>
         <source>Italic</source>
-        <translation type="unfinished"></translation>
+        <translation>مائل</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="83"/>
         <source>Bold Italic</source>
-        <translation type="unfinished"></translation>
+        <translation>ثخين مائل</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="94"/>
         <source>The following settings only affect newly started applications</source>
-        <translation type="unfinished"></translation>
+        <translation>ستؤثّر التعديلات الآتية على التطبيقات التي تبدأ بعد تطبيقها</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="100"/>
         <source>Use antialias fonts</source>
-        <translation type="unfinished"></translation>
+        <translation>استخدم خطوطا محسّنة حوافها</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="107"/>
         <source>Font hinting style:</source>
-        <translation type="unfinished"></translation>
+        <translation>نمط تلميحات الخطوط:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="118"/>
         <location filename="../fontsconfig.ui" line="183"/>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>بلا</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="123"/>
         <source>Slight</source>
-        <translation type="unfinished"></translation>
+        <translation>قليل</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="128"/>
         <source>Medium</source>
-        <translation type="unfinished"></translation>
+        <translation>وسط</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="133"/>
         <source>Full</source>
-        <translation type="unfinished"></translation>
+        <translation>كامل</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="141"/>
         <source>Font hinting</source>
-        <translation type="unfinished"></translation>
+        <translation>تلميحات الخطوط</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="148"/>
         <source>Resolution (DPI):</source>
-        <translation type="unfinished"></translation>
+        <translation>الميز (نقطة/بوصة):</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="155"/>
         <source>Autohint</source>
-        <translation type="unfinished"></translation>
+        <translation>التلميحات آليّة</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="172"/>
         <source>Subpixel antialiasing:</source>
-        <translation type="unfinished"></translation>
+        <translation>مضادّ تعرّج البكسلات الفرعية:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="188"/>
         <source>RGB</source>
-        <translation type="unfinished"></translation>
+        <translation>RGB</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="193"/>
         <source>BGR</source>
-        <translation type="unfinished"></translation>
+        <translation>BGR</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="198"/>
         <source>VRGB</source>
-        <translation type="unfinished"></translation>
+        <translation>VRGB</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="203"/>
         <source>VBGR</source>
-        <translation type="unfinished"></translation>
+        <translation>VBGR</translation>
     </message>
 </context>
 <context>
@@ -130,60 +143,68 @@
     <message>
         <location filename="../iconthemeconfig.ui" line="14"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>تهيئة مظهر ريزر</translation>
+        <translation>ضبط لكسكيوت للمظهر</translation>
     </message>
     <message>
         <location filename="../iconthemeconfig.ui" line="26"/>
         <source>Icons Theme</source>
-        <translation>نماذج اﻷيقونات</translation>
+        <translation>سمة الأيقونات</translation>
+    </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="87"/>
+        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
+        <translation>امتداد «كدي» لسمات أيقونات XDG ← ‏FollowsColorScheme (يتبع نمط الألوان)</translation>
+    </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="90"/>
+        <source>Colorize icons based on widget style (palette)</source>
+        <translation>لوّن الأيقونات حسب نمط الودجات (لوحة الألوان)</translation>
     </message>
 </context>
 <context>
     <name>LXQtThemeConfig</name>
-    <message>
-        <source>LXQt Theme</source>
-        <translation type="vanished">واجهة ريزر المخصَّصة</translation>
-    </message>
-</context>
-<context>
-    <name>LxQtThemeConfig</name>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="23"/>
         <source>LXQt Theme</source>
-        <translation type="unfinished">واجهة ريزر المخصَّصة</translation>
+        <translation>سمة لكسكيوت</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.ui" line="57"/>
+        <source>Override user-defined wallpaper</source>
+        <translation>تجاهل الخلفية التي عرّفها المستخدم</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="45"/>
+        <location filename="../main.cpp" line="58"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>تهيئة مظهر ريزر</translation>
+        <translation>ضبط لكسكيوت للمظهر</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="51"/>
+        <location filename="../main.cpp" line="67"/>
         <source>Widget Style</source>
-        <translation type="unfinished"></translation>
+        <translation>نمط الودجات</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="72"/>
         <source>Icons Theme</source>
-        <translation>نماذج اﻷيقونات</translation>
+        <translation>سمة الأيقونات</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="77"/>
         <source>LXQt Theme</source>
-        <translation>واجهة ريزر المخصَّصة</translation>
+        <translation>سمة لكسكيوت</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="63"/>
+        <location filename="../main.cpp" line="81"/>
         <source>Font</source>
-        <translation type="unfinished"></translation>
+        <translation>الخط</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="68"/>
+        <location filename="../main.cpp" line="87"/>
         <source>Cursor</source>
-        <translation type="unfinished"></translation>
+        <translation>المؤشّر</translation>
     </message>
 </context>
 <context>
@@ -191,41 +212,68 @@
     <message>
         <location filename="../styleconfig.ui" line="23"/>
         <source>Widget Style</source>
-        <translation type="unfinished"></translation>
+        <translation>نمط الودجات</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="54"/>
-        <source>Toolbar button style:</source>
+        <location filename="../styleconfig.ui" line="42"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="62"/>
-        <source>Only display the icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="67"/>
-        <source>Only display the text</source>
+        <source>GTK 3 Theme</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="72"/>
-        <source>The text appears beside the icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="77"/>
-        <source>The text appears under the icon</source>
+        <source>GTK 2 Theme</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="82"/>
-        <source>Default</source>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="90"/>
+        <location filename="../styleconfig.ui" line="99"/>
+        <source>Toolbar button style:</source>
+        <translation>نمط زر شريط الأدوات:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="107"/>
+        <source>Only display the icon</source>
+        <translation>اعرض الأيقونة فقط</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="112"/>
+        <source>Only display the text</source>
+        <translation>اعرض النص فقط</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="117"/>
+        <source>The text appears beside the icon</source>
+        <translation>يظهر النص بجانب الأيقونة</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="122"/>
+        <source>The text appears under the icon</source>
+        <translation>يظهر النص أسفل الأيقونة</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="127"/>
+        <source>Default</source>
+        <translation>المبدئي</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="135"/>
         <source>Activate item on single click</source>
+        <translation>فعّل العنصر بالنقر المفرد</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="145"/>
+        <source>Qt Style</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
