@@ -1,128 +1,141 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="cs">
+<context>
+    <name>ConfigOtherToolKits</name>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="144"/>
+        <source>GTK themes</source>
+        <translation>GTK motivy vzhledu</translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="145"/>
+        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
+        <translation>&lt;p&gt;„%1“ bylo přepsáno.&lt;/p&gt;&lt;p&gt;Kopie původních nastavení je k dispozici v „%2“&lt;/p&gt;</translation>
+    </message>
+</context>
 <context>
     <name>FontsConfig</name>
     <message>
         <location filename="../fontsconfig.ui" line="23"/>
         <source>Font</source>
-        <translation type="unfinished"></translation>
+        <translation>Písmo</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="30"/>
         <source>Default font for user interface</source>
-        <translation type="unfinished"></translation>
+        <translation>Výchozí písmo uživatelského rozhraní</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="36"/>
         <source>Font name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Název písma:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="46"/>
         <source>Style:</source>
-        <translation type="unfinished"></translation>
+        <translation>Styl:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="53"/>
         <source>Point size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Velikost v bodech:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="68"/>
         <source>Normal</source>
-        <translation type="unfinished"></translation>
+        <translation>Normální</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="73"/>
         <source>Bold</source>
-        <translation type="unfinished"></translation>
+        <translation>Tučné</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="78"/>
         <source>Italic</source>
-        <translation type="unfinished"></translation>
+        <translation>Kurzíva</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="83"/>
         <source>Bold Italic</source>
-        <translation type="unfinished"></translation>
+        <translation>Tučná kurzíva</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="94"/>
         <source>The following settings only affect newly started applications</source>
-        <translation type="unfinished"></translation>
+        <translation>Následující nastavení ovlivní pouze nově spuštěné aplikace</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="100"/>
         <source>Use antialias fonts</source>
-        <translation type="unfinished"></translation>
+        <translation>Vyhlazovat hrany písmen</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="107"/>
         <source>Font hinting style:</source>
-        <translation type="unfinished"></translation>
+        <translation>Styl doladění zobrazení písma:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="118"/>
         <location filename="../fontsconfig.ui" line="183"/>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>Žádné</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="123"/>
         <source>Slight</source>
-        <translation type="unfinished"></translation>
+        <translation>Lehké</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="128"/>
         <source>Medium</source>
-        <translation type="unfinished"></translation>
+        <translation>Střední</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="133"/>
         <source>Full</source>
-        <translation type="unfinished"></translation>
+        <translation>Plné</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="141"/>
         <source>Font hinting</source>
-        <translation type="unfinished"></translation>
+        <translation>Doladění zobrazení písma (hinting)</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="148"/>
         <source>Resolution (DPI):</source>
-        <translation type="unfinished"></translation>
+        <translation>Rozlišení na palec (DPI):</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="155"/>
         <source>Autohint</source>
-        <translation type="unfinished"></translation>
+        <translation>Automatické doladění zobrazení písma</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="172"/>
         <source>Subpixel antialiasing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Vyhlazování na úrovni dílčích segmentů bodů obrazovky:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="188"/>
         <source>RGB</source>
-        <translation type="unfinished"></translation>
+        <translation>RGB</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="193"/>
         <source>BGR</source>
-        <translation type="unfinished"></translation>
+        <translation>BGR</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="198"/>
         <source>VRGB</source>
-        <translation type="unfinished"></translation>
+        <translation>VRGB</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="203"/>
         <source>VBGR</source>
-        <translation type="unfinished"></translation>
+        <translation>VBGR</translation>
     </message>
 </context>
 <context>
@@ -130,60 +143,68 @@
     <message>
         <location filename="../iconthemeconfig.ui" line="14"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>Nastavení vzhledu</translation>
+        <translation>Nastavení vzhledu LXQt</translation>
     </message>
     <message>
         <location filename="../iconthemeconfig.ui" line="26"/>
         <source>Icons Theme</source>
         <translation>Téma ikon</translation>
     </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="87"/>
+        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
+        <translation>KDE rozšíření témat XDG ikon  -&gt; Následuje barevné schéma</translation>
+    </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="90"/>
+        <source>Colorize icons based on widget style (palette)</source>
+        <translation>Obarvovat ikony na základě stylu prvku (paleta)</translation>
+    </message>
 </context>
 <context>
     <name>LXQtThemeConfig</name>
-    <message>
-        <source>LXQt Theme</source>
-        <translation type="vanished">Motiv LXQt</translation>
-    </message>
-</context>
-<context>
-    <name>LxQtThemeConfig</name>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="23"/>
         <source>LXQt Theme</source>
-        <translation type="unfinished">Motiv LXQt</translation>
+        <translation>Téma vzhledu LXQt</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.ui" line="57"/>
+        <source>Override user-defined wallpaper</source>
+        <translation>Přepsat uživatelem určené pozadí plochy</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="45"/>
+        <location filename="../main.cpp" line="58"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>Nastavení vzhledu</translation>
+        <translation>Nastavení vzhledu LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="51"/>
+        <location filename="../main.cpp" line="67"/>
         <source>Widget Style</source>
-        <translation type="unfinished"></translation>
+        <translation>Styl obslužného prvku</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="72"/>
         <source>Icons Theme</source>
-        <translation>Téma ikon</translation>
+        <translation>Vzhled ikon</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="77"/>
         <source>LXQt Theme</source>
-        <translation>Motiv LXQt</translation>
+        <translation>Vzhled LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="63"/>
+        <location filename="../main.cpp" line="81"/>
         <source>Font</source>
-        <translation type="unfinished"></translation>
+        <translation>Písmo</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="68"/>
+        <location filename="../main.cpp" line="87"/>
         <source>Cursor</source>
-        <translation type="unfinished"></translation>
+        <translation>Ukazatel</translation>
     </message>
 </context>
 <context>
@@ -191,42 +212,71 @@
     <message>
         <location filename="../styleconfig.ui" line="23"/>
         <source>Widget Style</source>
-        <translation type="unfinished"></translation>
+        <translation>Styl obslužného prvku</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="54"/>
-        <source>Toolbar button style:</source>
-        <translation type="unfinished"></translation>
+        <location filename="../styleconfig.ui" line="42"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
+        <translation>Nastavit GTK motivy vzhledu (soubory s nastaveními GTK budou přepsány!)</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="62"/>
-        <source>Only display the icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="67"/>
-        <source>Only display the text</source>
-        <translation type="unfinished"></translation>
+        <source>GTK 3 Theme</source>
+        <translation>GTK 3 motiv vzhledu</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="72"/>
-        <source>The text appears beside the icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="77"/>
-        <source>The text appears under the icon</source>
-        <translation type="unfinished"></translation>
+        <source>GTK 2 Theme</source>
+        <translation>GTK 2 motiv vzhledu</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="82"/>
-        <source>Default</source>
-        <translation type="unfinished"></translation>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation>Pokud se chcete pokusit o jednotný motiv vzhledu, buď vyberte podobný styl / motiv vzhledu (pokud je k dispozici) napříč všemi seznamy, nebo vyberte Qt motiv vzhledu „gtk2“ (pokud je k dispozici) a napodobte tak GTK motivy vzhledu.
+
+Aby bylo možné u GTK aplikací změnit motiv vzhledu za chodu, ověřte, že je nainstalované „xsettingsd“.</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="90"/>
+        <location filename="../styleconfig.ui" line="99"/>
+        <source>Toolbar button style:</source>
+        <translation>Styl tlačítek v nástrojovém pruhu:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="107"/>
+        <source>Only display the icon</source>
+        <translation>Zobrazovat pouze ikonu</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="112"/>
+        <source>Only display the text</source>
+        <translation>Zobrazovat pouze text</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="117"/>
+        <source>The text appears beside the icon</source>
+        <translation>Text vedle ikony</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="122"/>
+        <source>The text appears under the icon</source>
+        <translation>Text pod ikonou</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="127"/>
+        <source>Default</source>
+        <translation>Výchozí</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="135"/>
         <source>Activate item on single click</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktivovat prvek jedním kliknutím</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="145"/>
+        <source>Qt Style</source>
+        <translation>Qt styl</translation>
     </message>
 </context>
 </TS>
