@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de">
+<TS version="2.1" language="de">
+<context>
+    <name>ConfigOtherToolKits</name>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="144"/>
+        <source>GTK themes</source>
+        <translation>GTK-Themen</translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="145"/>
+        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
+        <translation>&lt;p&gt;&apos;%1&apos; wurde überschrieben.&lt;/p&gt;&lt;p&gt;Sie finden eine Kopie Ihrer alten Einstellungen in &apos;%2&apos;&lt;/p&gt;</translation>
+    </message>
+</context>
 <context>
     <name>FontsConfig</name>
     <message>
@@ -29,98 +42,98 @@
         <translation>Punktgröße:</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="64"/>
+        <location filename="../fontsconfig.ui" line="68"/>
         <source>Normal</source>
         <translation>Normal</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="69"/>
+        <location filename="../fontsconfig.ui" line="73"/>
         <source>Bold</source>
         <translation>Fett</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="74"/>
+        <location filename="../fontsconfig.ui" line="78"/>
         <source>Italic</source>
         <translation>Kursiv</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="79"/>
+        <location filename="../fontsconfig.ui" line="83"/>
         <source>Bold Italic</source>
         <translation>Fett und kursiv</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="90"/>
+        <location filename="../fontsconfig.ui" line="94"/>
         <source>The following settings only affect newly started applications</source>
-        <translation>Folgende Einstellungen wirken nur auf neu gestartete Programme</translation>
+        <translation>Folgende Einstellungen beeinflussen nur neu gestartete Programme</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="96"/>
+        <location filename="../fontsconfig.ui" line="100"/>
         <source>Use antialias fonts</source>
         <translation>Kantenglättung bei Schriften verwenden</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="103"/>
+        <location filename="../fontsconfig.ui" line="107"/>
         <source>Font hinting style:</source>
-        <translation>Hinting-Stil:</translation>
+        <translation>Hintning-Stil:</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="114"/>
-        <location filename="../fontsconfig.ui" line="179"/>
+        <location filename="../fontsconfig.ui" line="118"/>
+        <location filename="../fontsconfig.ui" line="183"/>
         <source>None</source>
         <translation>Keine</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="119"/>
+        <location filename="../fontsconfig.ui" line="123"/>
         <source>Slight</source>
         <translation>Leicht</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="124"/>
+        <location filename="../fontsconfig.ui" line="128"/>
         <source>Medium</source>
         <translation>Mittel</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="129"/>
+        <location filename="../fontsconfig.ui" line="133"/>
         <source>Full</source>
         <translation>Vollständig</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="137"/>
+        <location filename="../fontsconfig.ui" line="141"/>
         <source>Font hinting</source>
         <translation>Schrift-Hinting</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="144"/>
+        <location filename="../fontsconfig.ui" line="148"/>
         <source>Resolution (DPI):</source>
         <translation>Auflösung (DPI):</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="151"/>
+        <location filename="../fontsconfig.ui" line="155"/>
         <source>Autohint</source>
         <translation>Autohint</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="168"/>
+        <location filename="../fontsconfig.ui" line="172"/>
         <source>Subpixel antialiasing:</source>
         <translation>Subpixel-Anordnung:</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="184"/>
+        <location filename="../fontsconfig.ui" line="188"/>
         <source>RGB</source>
         <translation>RGB</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="189"/>
+        <location filename="../fontsconfig.ui" line="193"/>
         <source>BGR</source>
         <translation>BGR</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="194"/>
+        <location filename="../fontsconfig.ui" line="198"/>
         <source>VRGB</source>
         <translation>VRGB</translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="199"/>
+        <location filename="../fontsconfig.ui" line="203"/>
         <source>VBGR</source>
         <translation>VBGR</translation>
     </message>
@@ -135,46 +148,61 @@
     <message>
         <location filename="../iconthemeconfig.ui" line="26"/>
         <source>Icons Theme</source>
-        <translation>Symboldesign</translation>
+        <translation>Symbolthema</translation>
+    </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="87"/>
+        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
+        <translation>Die KDE-Erweiterung der XDG-Symbolthemen -&gt; Folgt dem Farbschema</translation>
+    </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="90"/>
+        <source>Colorize icons based on widget style (palette)</source>
+        <translation>Symbole nach dem Stil der Bedienelemente einfärben (Palette)</translation>
     </message>
 </context>
 <context>
-    <name>LxQtThemeConfig</name>
+    <name>LXQtThemeConfig</name>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="23"/>
         <source>LXQt Theme</source>
-        <translation>LXQt-Design</translation>
+        <translation>LXQt-Thema</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.ui" line="57"/>
+        <source>Override user-defined wallpaper</source>
+        <translation>Benutzerdefinierten Schreibtischhintergrund überschreiben</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="45"/>
+        <location filename="../main.cpp" line="58"/>
         <source>LXQt Appearance Configuration</source>
         <translation>LXQt Erscheinungsbild-Konfiguration</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="51"/>
+        <location filename="../main.cpp" line="67"/>
         <source>Widget Style</source>
         <translation>Stil der Bedienelemente</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="72"/>
         <source>Icons Theme</source>
-        <translation>Symboldesign</translation>
+        <translation>Symbolthema</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="77"/>
         <source>LXQt Theme</source>
-        <translation>LXQt-Design</translation>
+        <translation>LXQt-Thema</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="63"/>
+        <location filename="../main.cpp" line="81"/>
         <source>Font</source>
         <translation>Schriftart</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="68"/>
+        <location filename="../main.cpp" line="87"/>
         <source>Cursor</source>
         <translation>Mauszeiger</translation>
     </message>
@@ -187,39 +215,66 @@
         <translation>Stil der Bedienelemente</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="54"/>
-        <source>Toolbar button style:</source>
-        <translation>Werkzeugleistenstil:</translation>
+        <location filename="../styleconfig.ui" line="42"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
+        <translation>GTK-Themen festlegen (GTK-Konfigurationsdateien werden überschrieben!)</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="62"/>
-        <source>Only display the icon</source>
-        <translation>Nur Symbol</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="67"/>
-        <source>Only display the text</source>
-        <translation>Nur Text</translation>
+        <source>GTK 3 Theme</source>
+        <translation>GTK 3-Thema</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="72"/>
-        <source>The text appears beside the icon</source>
-        <translation>Text neben dem Symbol</translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="77"/>
-        <source>The text appears under the icon</source>
-        <translation>Text unterhalb des Symbols</translation>
+        <source>GTK 2 Theme</source>
+        <translation>GTK 2-Thema</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="82"/>
-        <source>Default</source>
-        <translation>Default</translation>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="90"/>
+        <location filename="../styleconfig.ui" line="99"/>
+        <source>Toolbar button style:</source>
+        <translation>Werkzeugleisten-Schaltflächenstil:</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="107"/>
+        <source>Only display the icon</source>
+        <translation>Nur das Symbol anzeigen</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="112"/>
+        <source>Only display the text</source>
+        <translation>Nur den Text anzeigen</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="117"/>
+        <source>The text appears beside the icon</source>
+        <translation>Der Text erscheint neben dem Symbol</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="122"/>
+        <source>The text appears under the icon</source>
+        <translation>Der Text erscheint unter dem Symbol</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="127"/>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="135"/>
         <source>Activate item on single click</source>
-        <translation>Einfacher Klick aktiviert Elemente</translation>
+        <translation>Element mit einem einzigen Klick aktivieren</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="145"/>
+        <source>Qt Style</source>
+        <translation>Qt-Stil</translation>
     </message>
 </context>
 </TS>
