@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="es_VE">
+<context>
+    <name>ConfigOtherToolKits</name>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="144"/>
+        <source>GTK themes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="145"/>
+        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>FontsConfig</name>
     <message>
@@ -29,98 +42,98 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="64"/>
+        <location filename="../fontsconfig.ui" line="68"/>
         <source>Normal</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="69"/>
+        <location filename="../fontsconfig.ui" line="73"/>
         <source>Bold</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="74"/>
+        <location filename="../fontsconfig.ui" line="78"/>
         <source>Italic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="79"/>
+        <location filename="../fontsconfig.ui" line="83"/>
         <source>Bold Italic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="90"/>
+        <location filename="../fontsconfig.ui" line="94"/>
         <source>The following settings only affect newly started applications</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="96"/>
+        <location filename="../fontsconfig.ui" line="100"/>
         <source>Use antialias fonts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="103"/>
+        <location filename="../fontsconfig.ui" line="107"/>
         <source>Font hinting style:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="114"/>
-        <location filename="../fontsconfig.ui" line="179"/>
+        <location filename="../fontsconfig.ui" line="118"/>
+        <location filename="../fontsconfig.ui" line="183"/>
         <source>None</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="119"/>
+        <location filename="../fontsconfig.ui" line="123"/>
         <source>Slight</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="124"/>
+        <location filename="../fontsconfig.ui" line="128"/>
         <source>Medium</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="129"/>
+        <location filename="../fontsconfig.ui" line="133"/>
         <source>Full</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="137"/>
+        <location filename="../fontsconfig.ui" line="141"/>
         <source>Font hinting</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="144"/>
+        <location filename="../fontsconfig.ui" line="148"/>
         <source>Resolution (DPI):</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="151"/>
+        <location filename="../fontsconfig.ui" line="155"/>
         <source>Autohint</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="168"/>
+        <location filename="../fontsconfig.ui" line="172"/>
         <source>Subpixel antialiasing:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="184"/>
+        <location filename="../fontsconfig.ui" line="188"/>
         <source>RGB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="189"/>
+        <location filename="../fontsconfig.ui" line="193"/>
         <source>BGR</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="194"/>
+        <location filename="../fontsconfig.ui" line="198"/>
         <source>VRGB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../fontsconfig.ui" line="199"/>
+        <location filename="../fontsconfig.ui" line="203"/>
         <source>VBGR</source>
         <translation type="unfinished"></translation>
     </message>
@@ -137,51 +150,59 @@
         <source>Icons Theme</source>
         <translation>Tema de iconos</translation>
     </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="87"/>
+        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="90"/>
+        <source>Colorize icons based on widget style (palette)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LXQtThemeConfig</name>
-    <message>
-        <source>LXQt Theme</source>
-        <translation type="vanished">Tema LXQt</translation>
-    </message>
-</context>
-<context>
-    <name>LxQtThemeConfig</name>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="23"/>
         <source>LXQt Theme</source>
-        <translation type="unfinished">Tema LXQt</translation>
+        <translation>Tema LXQt</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.ui" line="57"/>
+        <source>Override user-defined wallpaper</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="45"/>
+        <location filename="../main.cpp" line="58"/>
         <source>LXQt Appearance Configuration</source>
         <translation>Configuración de apariencia de LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="51"/>
+        <location filename="../main.cpp" line="67"/>
         <source>Widget Style</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="72"/>
         <source>Icons Theme</source>
         <translation>Tema de iconos</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="77"/>
         <source>LXQt Theme</source>
         <translation>Tema LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="63"/>
+        <location filename="../main.cpp" line="81"/>
         <source>Font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="68"/>
+        <location filename="../main.cpp" line="87"/>
         <source>Cursor</source>
         <translation type="unfinished"></translation>
     </message>
@@ -194,39 +215,66 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="54"/>
-        <source>Toolbar button style:</source>
+        <location filename="../styleconfig.ui" line="42"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="62"/>
-        <source>Only display the icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="67"/>
-        <source>Only display the text</source>
+        <source>GTK 3 Theme</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="72"/>
-        <source>The text appears beside the icon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../styleconfig.ui" line="77"/>
-        <source>The text appears under the icon</source>
+        <source>GTK 2 Theme</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="82"/>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="99"/>
+        <source>Toolbar button style:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="107"/>
+        <source>Only display the icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="112"/>
+        <source>Only display the text</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="117"/>
+        <source>The text appears beside the icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="122"/>
+        <source>The text appears under the icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="127"/>
         <source>Default</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="90"/>
+        <location filename="../styleconfig.ui" line="135"/>
         <source>Activate item on single click</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../styleconfig.ui" line="145"/>
+        <source>Qt Style</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
