@@ -1,17 +1,30 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="it">
+<context>
+    <name>ConfigOtherToolKits</name>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="144"/>
+        <source>GTK themes</source>
+        <translation>Temi GTK</translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="145"/>
+        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
+        <translation>&lt;p&gt;&apos;%1&apos; è stato sovrascritto.&lt;/p&gt;&lt;p&gt;E&apos; presente una copia delle vecchie impostazioni in &apos;%2&apos;&lt;/p&gt;</translation>
+    </message>
+</context>
 <context>
     <name>FontsConfig</name>
     <message>
         <location filename="../fontsconfig.ui" line="23"/>
         <source>Font</source>
-        <translation>Caratteri</translation>
+        <translation>Carattere</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="30"/>
         <source>Default font for user interface</source>
-        <translation>Carattere generale</translation>
+        <translation>Carattere predefinito per l&apos;interfaccia utente</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="36"/>
@@ -51,17 +64,17 @@
     <message>
         <location filename="../fontsconfig.ui" line="94"/>
         <source>The following settings only affect newly started applications</source>
-        <translation>Le impostazioni riguardano solo le applicazioni avviate nuovamente</translation>
+        <translation>Le impostazioni riguardano solo le applicazioni appena avviate</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="100"/>
         <source>Use antialias fonts</source>
-        <translation>Utilizza anti-aliasing per i caratteri</translation>
+        <translation>Utilizza l&apos;anti-aliasing per i caratteri</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="107"/>
         <source>Font hinting style:</source>
-        <translation>Stile di hinting</translation>
+        <translation>Stile di hinting del carattere:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="118"/>
@@ -82,7 +95,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="133"/>
         <source>Full</source>
-        <translation>Forte</translation>
+        <translation>Intero</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="141"/>
@@ -103,7 +116,7 @@
         <location filename="../fontsconfig.ui" line="172"/>
         <source>Subpixel antialiasing:</source>
         <translatorcomment>no idea how to translate that</translatorcomment>
-        <translation type="unfinished"></translation>
+        <translation>Antialiasing dei subpixel:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="188"/>
@@ -131,53 +144,68 @@
     <message>
         <location filename="../iconthemeconfig.ui" line="14"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>Centro di Configurazione LXQt</translation>
+        <translation>Aspetto di LXQt</translation>
     </message>
     <message>
         <location filename="../iconthemeconfig.ui" line="26"/>
         <source>Icons Theme</source>
         <translation>Temi delle icone</translation>
     </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="87"/>
+        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
+        <translation>L&apos;estensione KDE di temi icone XDG -&gt; segui schema colori</translation>
+    </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="90"/>
+        <source>Colorize icons based on widget style (palette)</source>
+        <translation>Colore delle icone basato su stile degli elementi</translation>
+    </message>
 </context>
 <context>
-    <name>LxQtThemeConfig</name>
+    <name>LXQtThemeConfig</name>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="23"/>
         <source>LXQt Theme</source>
         <translation>Tema di LXQt</translation>
     </message>
+    <message>
+        <location filename="../lxqtthemeconfig.ui" line="57"/>
+        <source>Override user-defined wallpaper</source>
+        <translation>Sostituisci sfondo desktop personalizzato</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="45"/>
+        <location filename="../main.cpp" line="58"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>Centro di Configurazione LXQt</translation>
+        <translation>Configurazione dell&apos;aspetto di LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="51"/>
+        <location filename="../main.cpp" line="67"/>
         <source>Widget Style</source>
         <translation>Stile degli elementi</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="72"/>
         <source>Icons Theme</source>
         <translation>Tema delle icone</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="77"/>
         <source>LXQt Theme</source>
         <translation>Tema di LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="63"/>
+        <location filename="../main.cpp" line="81"/>
         <source>Font</source>
-        <translation>Caratteri</translation>
+        <translation>Carattere</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="68"/>
+        <location filename="../main.cpp" line="87"/>
         <source>Cursor</source>
-        <translation>Cursore</translation>
+        <translation>Puntatore</translation>
     </message>
 </context>
 <context>
@@ -188,39 +216,68 @@
         <translation>Stile degli elementi</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="54"/>
+        <location filename="../styleconfig.ui" line="42"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
+        <translation>Imposta tema GTK (verranno sovrascritti i file di configurazione di GTK!)</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="62"/>
+        <source>GTK 3 Theme</source>
+        <translation>Tema GTK 3</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="72"/>
+        <source>GTK 2 Theme</source>
+        <translation>Tema GTK 2</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="82"/>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation>Per provare ad uniformare il tema, seleziona uno stile/tema simile (se disponibile) nella lista, o seleziona &apos;gtk2&apos; Qt style (se disponibile) per mimare i temi GTK. 
+
+Assicurati che &apos;xsettingsd&apos; sia installato per aiutare le applicazioni GTK ad applicare i temi automaticamente.</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="99"/>
         <source>Toolbar button style:</source>
         <translation>Stile della barra delle applicazioni:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="62"/>
+        <location filename="../styleconfig.ui" line="107"/>
         <source>Only display the icon</source>
-        <translation>Mostra solo icone</translation>
+        <translation>Mostra solo l&apos;icona</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="67"/>
+        <location filename="../styleconfig.ui" line="112"/>
         <source>Only display the text</source>
-        <translation>Mostra solo testo</translation>
+        <translation>Mostra solo il testo</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="72"/>
+        <location filename="../styleconfig.ui" line="117"/>
         <source>The text appears beside the icon</source>
-        <translation>Testo accanto le icone</translation>
+        <translation>Testo accanto all&apos;icona</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="77"/>
+        <location filename="../styleconfig.ui" line="122"/>
         <source>The text appears under the icon</source>
-        <translation>Testo sotto le icone</translation>
+        <translation>Testo sotto l&apos;icona</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="82"/>
+        <location filename="../styleconfig.ui" line="127"/>
         <source>Default</source>
-        <translation type="unfinished"></translation>
+        <translation>Predefinito</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="90"/>
+        <location filename="../styleconfig.ui" line="135"/>
         <source>Activate item on single click</source>
-        <translation>Attiva elementi con clic singolo</translation>
+        <translation>Attiva elementi con un clic singolo</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="145"/>
+        <source>Qt Style</source>
+        <translation>Stile Qt</translation>
     </message>
 </context>
 </TS>
