@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ru">
+<context>
+    <name>ConfigOtherToolKits</name>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="144"/>
+        <source>GTK themes</source>
+        <translation>Темы GTK</translation>
+    </message>
+    <message>
+        <location filename="../configothertoolkits.cpp" line="145"/>
+        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
+        <translation>&lt;p&gt;«%1» был перезаписан.&lt;/p&gt;&lt;p&gt;Копия прежних настроек находится в «%2»&lt;/p&gt;</translation>
+    </message>
+</context>
 <context>
     <name>FontsConfig</name>
     <message>
@@ -51,7 +64,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="94"/>
         <source>The following settings only affect newly started applications</source>
-        <translation>Следующие настройки подействуют только на вновь запущенные приложения</translation>
+        <translation>Настройки будут применены к вновь запущенным приложениям</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="100"/>
@@ -130,51 +143,66 @@
     <message>
         <location filename="../iconthemeconfig.ui" line="14"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>Меню программ</translation>
+        <translation>Настройка внешнего вида LXQt</translation>
     </message>
     <message>
         <location filename="../iconthemeconfig.ui" line="26"/>
         <source>Icons Theme</source>
-        <translation>Иконки темы</translation>
+        <translation>Тема Значков</translation>
+    </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="87"/>
+        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
+        <translation>Расширение KDE тем значков XDG -&gt; FollowsColorScheme</translation>
+    </message>
+    <message>
+        <location filename="../iconthemeconfig.ui" line="90"/>
+        <source>Colorize icons based on widget style (palette)</source>
+        <translation>Цвет значков в соответствии с палитрой виджетов</translation>
     </message>
 </context>
 <context>
-    <name>LxQtThemeConfig</name>
+    <name>LXQtThemeConfig</name>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="23"/>
         <source>LXQt Theme</source>
         <translation>Тема LXQt</translation>
     </message>
+    <message>
+        <location filename="../lxqtthemeconfig.ui" line="57"/>
+        <source>Override user-defined wallpaper</source>
+        <translation>Заменить пользовательские обои</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="45"/>
+        <location filename="../main.cpp" line="58"/>
         <source>LXQt Appearance Configuration</source>
         <translation>Настройка внешнего вида LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="55"/>
+        <location filename="../main.cpp" line="72"/>
         <source>Icons Theme</source>
         <translation>Тема иконок</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="59"/>
+        <location filename="../main.cpp" line="77"/>
         <source>LXQt Theme</source>
-        <translation>LXQt темы</translation>
+        <translation>Тема LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="51"/>
+        <location filename="../main.cpp" line="67"/>
         <source>Widget Style</source>
         <translation>Стиль виджетов</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="63"/>
+        <location filename="../main.cpp" line="81"/>
         <source>Font</source>
         <translation>Шрифт</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="68"/>
+        <location filename="../main.cpp" line="87"/>
         <source>Cursor</source>
         <translation>Курсор</translation>
     </message>
@@ -187,39 +215,68 @@
         <translation>Стиль виджетов</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="54"/>
+        <location filename="../styleconfig.ui" line="42"/>
+        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
+        <translation>Установить темы GTK (будет перезаписан файл конфигурации GTK)</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="62"/>
+        <source>GTK 3 Theme</source>
+        <translation>Тема GTK 3</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="72"/>
+        <source>GTK 2 Theme</source>
+        <translation>Тема GTK 2</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="82"/>
+        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
+
+Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
+        <translation>Чтобы добиться одинакового внешнего вида всех приложений, или выберите похожие стили/темы (по возможности) во всех списках, или выберите стиль &apos;gtk2&apos; для Qt (по возможности), дабы он имитировал тему GTK.
+
+Удостоверьтесь, что «xsettingsd» установлен, чтобы GTK-приложения могли применять темы «на лету».</translation>
+    </message>
+    <message>
+        <location filename="../styleconfig.ui" line="99"/>
         <source>Toolbar button style:</source>
         <translation>Стиль кнопок панели:</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="62"/>
+        <location filename="../styleconfig.ui" line="107"/>
         <source>Only display the icon</source>
-        <translation>Показывать только иконку</translation>
+        <translation>Показывать только значок</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="67"/>
+        <location filename="../styleconfig.ui" line="112"/>
         <source>Only display the text</source>
         <translation>Показывать только текст</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="72"/>
+        <location filename="../styleconfig.ui" line="117"/>
         <source>The text appears beside the icon</source>
-        <translation>Текст появляется сбоку от иконки</translation>
+        <translation>Текст появляется сбоку от значка</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="77"/>
+        <location filename="../styleconfig.ui" line="122"/>
         <source>The text appears under the icon</source>
-        <translation>Текст появляется под иконкой</translation>
+        <translation>Текст появляется под значком</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="82"/>
+        <location filename="../styleconfig.ui" line="127"/>
         <source>Default</source>
         <translation>По умолчанию</translation>
     </message>
     <message>
-        <location filename="../styleconfig.ui" line="90"/>
+        <location filename="../styleconfig.ui" line="135"/>
         <source>Activate item on single click</source>
         <translation>Активировать элемент по одиночному щелчку мыши</translation>
     </message>
+    <message>
+        <location filename="../styleconfig.ui" line="145"/>
+        <source>Qt Style</source>
+        <translation>Стиль Qt</translation>
+    </message>
 </context>
 </TS>
