@@ -1,16 +1,16 @@
 /*
     Copyright (C) 2016  P.L. Lucas <selairi@gmail.com>
-    
+
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
     License as published by the Free Software Foundation; either
     version 2.1 of the License, or (at your option) any later version.
-    
+
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     Lesser General Public License for more details.
-    
+
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -25,11 +25,22 @@ BrightnessSettings::BrightnessSettings(QWidget *parent):QDialog(parent)
 {
     ui = new Ui::BrightnessSettings();
     ui->setupUi(this);
-    
+
     mBrightness = new XRandrBrightness();
     mMonitors = mBrightness->getMonitorsInfo();
+    mBacklight = new LXQt::Backlight(this);
 
-    for(const MonitorInfo &monitor: mMonitors)
+    ui->backlightSlider->setEnabled(mBacklight->isBacklightAvailable() || mBacklight->isBacklightOff());
+    if(mBacklight->isBacklightAvailable()) {
+        ui->backlightSlider->setMaximum(mBacklight->getMaxBacklight());
+        // set the minimum to 5% of the maximum to prevent a black screen
+        ui->backlightSlider->setMinimum(qMax(qRound((qreal)(mBacklight->getMaxBacklight())*0.05), 1));
+        ui->backlightSlider->setValue(mLastBacklightValue = mBacklight->getBacklight());
+        // Don't change the backlight too quickly
+        connect(ui->backlightSlider, &QSlider::valueChanged, [this] {mBacklightTimer.start();});
+    }
+
+    for(const MonitorInfo &monitor: qAsConst(mMonitors))
     {
         OutputWidget *output = new OutputWidget(monitor, this);
         ui->layout->addWidget(output);
@@ -38,10 +49,19 @@ BrightnessSettings::BrightnessSettings(QWidget *parent):QDialog(parent)
         connect(this, &BrightnessSettings::monitorReverted, output, &OutputWidget::setRevertedValues);
     }
 
+    mBacklightTimer.setSingleShot(true);
+    mBacklightTimer.setInterval(250);
+    connect(&mBacklightTimer, &QTimer::timeout, this, &BrightnessSettings::setBacklight);
+
     mConfirmRequestTimer.setSingleShot(true);
     mConfirmRequestTimer.setInterval(1000);
     connect(&mConfirmRequestTimer, &QTimer::timeout, this, &BrightnessSettings::requestConfirmation);
-    
+
+}
+
+void BrightnessSettings::setBacklight()
+{
+    mBacklight->setBacklight(ui->backlightSlider->value());
 }
 
 void BrightnessSettings::monitorSettingsChanged(MonitorInfo monitor)
@@ -90,12 +110,22 @@ void BrightnessSettings::requestConfirmation()
     if (QMessageBox::Yes == msg.exec())
     {
         // re-read current values
+        if(mBacklight->isBacklightAvailable())
+            mLastBacklightValue = mBacklight->getBacklight();
+
         mMonitors = mBrightness->getMonitorsInfo();
     } else
     {
         // revert the changes
+        if(mBacklight->isBacklightAvailable()) {
+            disconnect(ui->backlightSlider, &QSlider::valueChanged, this, &BrightnessSettings::setBacklight);
+            mBacklight->setBacklight(mLastBacklightValue);
+            ui->backlightSlider->setValue(mLastBacklightValue);
+            connect(ui->backlightSlider, &QSlider::valueChanged, this, &BrightnessSettings::setBacklight);
+        }
+
         mBrightness->setMonitorsSettings(mMonitors);
-        for (const auto & monitor : mMonitors)
+        for (const auto & monitor : qAsConst(mMonitors))
             emit monitorReverted(monitor);
     }
 }
