@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * https://lxqt.org
  *
  * Copyright: 2013 Christian Surlykke
  *            2014 Luís Pereira <luis.artur.pereira.gmail.com>
@@ -34,7 +34,6 @@
 #include <QDateTime>
 #include <QFileInfo>
 
-#include <XdgIcon>
 #include <XdgDesktopFile>
 #include <XdgDirs>
 #include <LXQt/Settings>
@@ -67,7 +66,7 @@ void MimetypeViewer::loadAllMimeTypes()
     QList<QMimeType> mimetypes = db.allMimeTypes();
 
     qSort(mimetypes.begin(), mimetypes.end(), mimeTypeLessThan);
-    foreach (const QMimeType &mt, mimetypes) {
+    for (const QMimeType &mt : qAsConst(mimetypes)) {
         const QString mimetype = mt.name();
         const int i = mimetype.indexOf(QLatin1Char('/'));
         const QString mediaType = mimetype.left(i);
@@ -108,12 +107,13 @@ MimetypeViewer::MimetypeViewer(QWidget *parent)
     connect(widget.chooseApplicationsButton, SIGNAL(clicked()), this, SLOT(chooseApplication()));
     connect(widget.dialogButtonBox, SIGNAL(clicked(QAbstractButton*)), this, SLOT(dialogButtonBoxClicked(QAbstractButton*)));
 
-    QString mimeappsListPath(XdgDirs::dataHome(true) + "/applications/mimeapps.list");
+    QString mimeappsListPath(XdgDirs::configHome(true) + "/mimeapps.list");
     mDefaultsList = new QSettings(mimeappsListPath, XdgDesktopFileCache::desktopFileSettingsFormat(), this);
-    mSettingsCache = new LxQt::SettingsCache(mDefaultsList);
+    mSettingsCache = new LXQt::SettingsCache(mDefaultsList);
     mSettingsCache->loadFromSettings();
     initializeMimetypeTreeView();
     loadAllMimeTypes();
+    widget.searchTermLineEdit->setFocus();
 
     connect(widget.mimetypeTreeWidget, SIGNAL(itemSelectionChanged()),
             this, SLOT(currentMimetypeChanged()));
@@ -147,7 +147,6 @@ void MimetypeViewer::initializeMimetypeTreeView()
 {
     currentMimetypeChanged();
     widget.mimetypeTreeWidget->setColumnCount(2);
-    widget.mimetypeTreeWidget->setFocus();
     widget.searchTermLineEdit->setEnabled(true);
 }
 
@@ -217,13 +216,12 @@ void MimetypeViewer::filter(const QString& pattern)
 {
     QMimeDatabase db;
     MimeTypeData mimeData;
-    const int count = widget.mimetypeTreeWidget->topLevelItemCount();
 
     for (int i = 0; i < widget.mimetypeTreeWidget->topLevelItemCount(); ++i) {
         widget.mimetypeTreeWidget->topLevelItem(i)->setHidden(true);
     }
 
-    foreach(QTreeWidgetItem* it, mItemList) {
+    for(QTreeWidgetItem* it : qAsConst(mItemList)) {
         mimeData = it->data(0, Qt::UserRole).value<MimeTypeData>();
         if (pattern.isEmpty() || mimeData.matches(pattern)) {
             const int i = mimeData.name().indexOf(QLatin1Char('/'));
