@@ -1,17 +1,17 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de">
+<TS version="2.1" language="de">
 <context>
     <name>ApplicationChooser</name>
     <message>
         <location filename="../applicationchooser.ui" line="14"/>
         <source>ApplicationChooser</source>
-        <translation>Dateizuordnungen</translation>
+        <translation>Anwendungsauswahl</translation>
     </message>
     <message>
         <location filename="../applicationchooser.ui" line="46"/>
         <source>Pick an application for:</source>
-        <translation>Anwendung auswählen für:</translation>
+        <translation>Wählen Sie eine Anwendung aus für:</translation>
     </message>
     <message>
         <location filename="../applicationchooser.ui" line="110"/>
@@ -21,7 +21,7 @@
     <message>
         <location filename="../applicationchooser.ui" line="115"/>
         <source>Applications that handle JPEG</source>
-        <translation>Anwendungen die JPEG verarbeiten</translation>
+        <translation>Anwendungen, die JPEG verarbeiten</translation>
     </message>
     <message>
         <location filename="../applicationchooser.ui" line="124"/>
@@ -33,36 +33,36 @@
     </message>
     <message>
         <location filename="../applicationchooser.ui" line="135"/>
-        <location filename="../applicationchooser.cpp" line="85"/>
+        <location filename="../applicationchooser.cpp" line="113"/>
         <source>Other applications</source>
-        <translation>Andere Anwendung</translation>
-    </message>
-    <message>
-        <location filename="../applicationchooser.cpp" line="86"/>
-        <source>Applications that handle %1</source>
-        <translation>Anwendungen die %1 verarbeiten</translation>
+        <translation>Andere Anwendungen</translation>
     </message>
     <message>
         <location filename="../applicationchooser.cpp" line="114"/>
+        <source>Applications that handle %1</source>
+        <translation>Anwendungen, die %1 verarbeiten</translation>
+    </message>
+    <message>
+        <location filename="../applicationchooser.cpp" line="151"/>
         <source>No applications found</source>
-        <translation>Keine Anwendung gefunden</translation>
+        <translation>Keine Anwendungen gefunden</translation>
     </message>
 </context>
 <context>
     <name>MimetypeViewer</name>
     <message>
-        <location filename="../mimetypeviewer.cpp" line="157"/>
-        <location filename="../mimetypeviewer.cpp" line="208"/>
+        <location filename="../mimetypeviewer.cpp" line="156"/>
+        <location filename="../mimetypeviewer.cpp" line="207"/>
         <source>None</source>
         <translation>Keine</translation>
     </message>
     <message>
-        <location filename="../mimetypeviewer.cpp" line="204"/>
+        <location filename="../mimetypeviewer.cpp" line="203"/>
         <source>&amp;Change...</source>
-        <translation>Ä&amp;ndern...</translation>
+        <translation>&amp;Ändern...</translation>
     </message>
     <message>
-        <location filename="../mimetypeviewer.cpp" line="209"/>
+        <location filename="../mimetypeviewer.cpp" line="208"/>
         <source>&amp;Choose...</source>
         <translation>&amp;Auswählen...</translation>
     </message>
@@ -77,7 +77,7 @@
     <message>
         <location filename="../mimetypeviewer.ui" line="56"/>
         <source>Default application</source>
-        <translation>Default-Anwendungsprogramm</translation>
+        <translation>Standardanwendung</translation>
     </message>
     <message>
         <location filename="../mimetypeviewer.ui" line="68"/>
@@ -87,17 +87,17 @@
     <message>
         <location filename="../mimetypeviewer.ui" line="117"/>
         <source>TextLabel</source>
-        <translation>Textfeld</translation>
+        <translation>Textkennzeichen</translation>
     </message>
     <message>
         <location filename="../mimetypeviewer.ui" line="124"/>
         <source>None</source>
-        <translation>Keins</translation>
+        <translation>Keine</translation>
     </message>
     <message>
         <location filename="../mimetypeviewer.ui" line="144"/>
         <source>Patterns</source>
-        <translation>Dateimuster</translation>
+        <translation>Muster</translation>
     </message>
     <message>
         <location filename="../mimetypeviewer.ui" line="156"/>
