@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="it_IT" sourcelanguage="it_IT">
+<TS version="2.1" language="it" sourcelanguage="it_IT">
 <context>
     <name>ApplicationChooser</name>
     <message>
@@ -11,7 +11,7 @@
     <message>
         <location filename="../applicationchooser.ui" line="46"/>
         <source>Pick an application for:</source>
-        <translation>Scegli un applicazione per:</translation>
+        <translation>Scegli un&apos;applicazione per:</translation>
     </message>
     <message>
         <location filename="../applicationchooser.ui" line="110"/>
@@ -29,21 +29,21 @@
         <location filename="../applicationchooser.ui" line="139"/>
         <location filename="../applicationchooser.ui" line="144"/>
         <source>New Subitem</source>
-        <translation></translation>
+        <translation>Nuovo sottoelemento</translation>
     </message>
     <message>
         <location filename="../applicationchooser.ui" line="135"/>
-        <location filename="../applicationchooser.cpp" line="85"/>
+        <location filename="../applicationchooser.cpp" line="113"/>
         <source>Other applications</source>
         <translation>Altre applicazioni</translation>
     </message>
     <message>
-        <location filename="../applicationchooser.cpp" line="86"/>
+        <location filename="../applicationchooser.cpp" line="114"/>
         <source>Applications that handle %1</source>
         <translation>Applicazioni che possono gestire %1</translation>
     </message>
     <message>
-        <location filename="../applicationchooser.cpp" line="114"/>
+        <location filename="../applicationchooser.cpp" line="151"/>
         <source>No applications found</source>
         <translation>Nessuna applicazione trovata</translation>
     </message>
@@ -51,18 +51,18 @@
 <context>
     <name>MimetypeViewer</name>
     <message>
-        <location filename="../mimetypeviewer.cpp" line="157"/>
-        <location filename="../mimetypeviewer.cpp" line="208"/>
+        <location filename="../mimetypeviewer.cpp" line="156"/>
+        <location filename="../mimetypeviewer.cpp" line="207"/>
         <source>None</source>
         <translation>Nessuno</translation>
     </message>
     <message>
-        <location filename="../mimetypeviewer.cpp" line="204"/>
+        <location filename="../mimetypeviewer.cpp" line="203"/>
         <source>&amp;Change...</source>
         <translation>&amp;Cambia...</translation>
     </message>
     <message>
-        <location filename="../mimetypeviewer.cpp" line="209"/>
+        <location filename="../mimetypeviewer.cpp" line="208"/>
         <source>&amp;Choose...</source>
         <translation>&amp;Scegli...</translation>
     </message>
@@ -87,17 +87,17 @@
     <message>
         <location filename="../mimetypeviewer.ui" line="117"/>
         <source>TextLabel</source>
-        <translation></translation>
+        <translation>EtichettaTesto</translation>
     </message>
     <message>
         <location filename="../mimetypeviewer.ui" line="124"/>
         <source>None</source>
-        <translation></translation>
+        <translation>Nessuna</translation>
     </message>
     <message>
         <location filename="../mimetypeviewer.ui" line="144"/>
         <source>Patterns</source>
-        <translation>Tipi di file</translation>
+        <translation>Modelli</translation>
     </message>
     <message>
         <location filename="../mimetypeviewer.ui" line="156"/>
