@@ -66,6 +66,11 @@
         <source>0</source>
         <translation type="unfinished">0</translation>
     </message>
+    <message>
+        <location filename="../keyboardconfig.ui" line="167"/>
+        <source>Turn on NumLock after login</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>KeyboardLayoutConfig</name>
@@ -96,12 +101,12 @@
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="77"/>
-        <source>up</source>
+        <source>Up</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="84"/>
-        <source>down</source>
+        <source>Down</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -125,77 +130,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>MainDialog</name>
-    <message>
-        <source>Input Device Preferences</source>
-        <translation type="vanished">Sarrerako gailuaren hobespenak</translation>
-    </message>
-    <message>
-        <source>Motion</source>
-        <translation type="vanished">Mugimendua</translation>
-    </message>
-    <message>
-        <source>High</source>
-        <translation type="vanished">Altua</translation>
-    </message>
-    <message>
-        <source>Fast</source>
-        <translation type="vanished">Azkarra</translation>
-    </message>
-    <message>
-        <source>Sensitivity:</source>
-        <translation type="vanished">Sentikortasuna:</translation>
-    </message>
-    <message>
-        <source>Low</source>
-        <translation type="vanished">Baxua</translation>
-    </message>
-    <message>
-        <source>Acceleration:</source>
-        <translation type="vanished">Azelerazioa:</translation>
-    </message>
-    <message>
-        <source>Slow</source>
-        <translation type="vanished">Mantsoa</translation>
-    </message>
-    <message>
-        <source>0</source>
-        <translation type="vanished">0</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation type="vanished">Sagua</translation>
-    </message>
-    <message>
-        <source>Character Repeat</source>
-        <translation type="vanished">Karaktere-errepikapena</translation>
-    </message>
-    <message>
-        <source>Long</source>
-        <translation type="vanished">Luzea</translation>
-    </message>
-    <message>
-        <source>Repeat delay:</source>
-        <translation type="vanished">Errepikatze atzerapena:</translation>
-    </message>
-    <message>
-        <source>Short</source>
-        <translation type="vanished">Laburra</translation>
-    </message>
-    <message>
-        <source>Repeat interval:</source>
-        <translation type="vanished">Errepikatze tartea:</translation>
-    </message>
-    <message>
-        <source>Type in the following box to test your keyboard settings</source>
-        <translation type="vanished">Idatzi ondorengo testu-koadroan zure teklatuaren ezarpenak probatzeko</translation>
-    </message>
-    <message>
-        <source>Keyboard</source>
-        <translation type="vanished">Teklatua</translation>
-    </message>
-</context>
 <context>
     <name>MouseConfig</name>
     <message>
@@ -278,27 +212,27 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="34"/>
+        <location filename="../lxqt-config-input.cpp" line="51"/>
         <source>Keyboard and Mouse Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="39"/>
+        <location filename="../lxqt-config-input.cpp" line="56"/>
         <source>Mouse</source>
         <translation type="unfinished">Sagua</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="44"/>
+        <location filename="../lxqt-config-input.cpp" line="61"/>
         <source>Cursor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="47"/>
+        <location filename="../lxqt-config-input.cpp" line="64"/>
         <source>Keyboard</source>
         <translation type="unfinished">Teklatua</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="51"/>
+        <location filename="../lxqt-config-input.cpp" line="68"/>
         <source>Keyboard Layout</source>
         <translation type="unfinished"></translation>
     </message>
