@@ -6,65 +6,70 @@
     <message>
         <location filename="../keyboardconfig.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>Formulir</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="20"/>
         <source>Cursor flash time:</source>
-        <translation type="unfinished"></translation>
+        <translation>Waktu kilat kursor:</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="27"/>
         <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Papan Tik&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="34"/>
         <source>Beep when there is an error of keyboard input</source>
-        <translation type="unfinished">Bip ketika ada galat masukan papan tik</translation>
+        <translation>Bip ketika ada kesalahan masukan papan tik</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="41"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="51"/>
         <source>Character Repeat</source>
-        <translation type="unfinished">Pengulangan Karakter</translation>
+        <translation>Pengulangan Karakter</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="79"/>
         <location filename="../keyboardconfig.ui" line="143"/>
         <source>Long</source>
-        <translation type="unfinished">Lama</translation>
+        <translation>Lama</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="108"/>
         <source>Repeat delay:</source>
-        <translation type="unfinished">Tundaan pengulangan:</translation>
+        <translation>Tundaan pengulangan:</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="115"/>
         <location filename="../keyboardconfig.ui" line="136"/>
         <source>Short</source>
-        <translation type="unfinished">Singkat</translation>
+        <translation>Singkat</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="122"/>
         <source>Repeat interval:</source>
-        <translation type="unfinished">Interval pengulangan:</translation>
+        <translation>Interval pengulangan:</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="129"/>
         <source>Type in the following box to test your keyboard settings</source>
-        <translation type="unfinished">Ketik dalam kotak berikut untuk menguji pengaturan papan tik Anda</translation>
+        <translation>Ketik dalam kotak berikut untuk menguji pengaturan papan tik Anda</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="150"/>
         <location filename="../keyboardconfig.ui" line="157"/>
         <source>0</source>
-        <translation type="unfinished">0</translation>
+        <translation>0</translation>
+    </message>
+    <message>
+        <location filename="../keyboardconfig.ui" line="167"/>
+        <source>Turn on NumLock after login</source>
+        <translation>Hidupkan NumLock setelah masuk</translation>
     </message>
 </context>
 <context>
@@ -72,136 +77,57 @@
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="20"/>
         <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Teta Letak Papan Tik&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="48"/>
         <source>Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Tata letak</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="53"/>
         <source>Variant</source>
-        <translation type="unfinished"></translation>
+        <translation>Varian</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="63"/>
         <source>&amp;Add</source>
-        <translation type="unfinished"></translation>
+        <translation>Tambah</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="70"/>
         <source>&amp;Remove</source>
-        <translation type="unfinished"></translation>
+        <translation>Hapus</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="77"/>
-        <source>up</source>
-        <translation type="unfinished"></translation>
+        <source>Up</source>
+        <translation>Atas</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="84"/>
-        <source>down</source>
-        <translation type="unfinished"></translation>
+        <source>Down</source>
+        <translation>Bawah</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="108"/>
         <source>Keyboard model:</source>
-        <translation type="unfinished"></translation>
+        <translation>Model papan tik:</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="122"/>
         <source>Keys to change layout:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tombol untuk mengubah tata letak:</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="133"/>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>Tidak ada</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="141"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
-<context>
-    <name>MainDialog</name>
-    <message>
-        <source>Input Device Preferences</source>
-        <translation type="vanished">Preferensi Perangkat Masukan</translation>
-    </message>
-    <message>
-        <source>Motion</source>
-        <translation type="vanished">Gerakan</translation>
-    </message>
-    <message>
-        <source>High</source>
-        <translation type="vanished">Tinggi</translation>
-    </message>
-    <message>
-        <source>Fast</source>
-        <translation type="vanished">Cepat</translation>
-    </message>
-    <message>
-        <source>Sensitivity:</source>
-        <translation type="vanished">Sensitivitas:</translation>
-    </message>
-    <message>
-        <source>Low</source>
-        <translation type="vanished">Rendah</translation>
-    </message>
-    <message>
-        <source>Acceleration:</source>
-        <translation type="vanished">Akselerasi:</translation>
-    </message>
-    <message>
-        <source>Slow</source>
-        <translation type="vanished">Lambat</translation>
-    </message>
-    <message>
-        <source>0</source>
-        <translation type="vanished">0</translation>
-    </message>
-    <message>
-        <source>Left handed (Swap left and right mouse buttons)</source>
-        <translation type="vanished">Kidal (Tukar tombol tetikus kiri dan kanan)</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation type="vanished">Tetikus</translation>
-    </message>
-    <message>
-        <source>Character Repeat</source>
-        <translation type="vanished">Pengulangan Karakter</translation>
-    </message>
-    <message>
-        <source>Long</source>
-        <translation type="vanished">Lama</translation>
-    </message>
-    <message>
-        <source>Repeat delay:</source>
-        <translation type="vanished">Tundaan pengulangan:</translation>
-    </message>
-    <message>
-        <source>Short</source>
-        <translation type="vanished">Singkat</translation>
-    </message>
-    <message>
-        <source>Repeat interval:</source>
-        <translation type="vanished">Interval pengulangan:</translation>
-    </message>
-    <message>
-        <source>Type in the following box to test your keyboard settings</source>
-        <translation type="vanished">Ketik dalam kotak berikut untuk menguji pengaturan papan tik Anda</translation>
-    </message>
-    <message>
-        <source>Beep when there is an error of keyboard input</source>
-        <translation type="vanished">Bip ketika ada galat masukan papan tik</translation>
-    </message>
-    <message>
-        <source>Keyboard</source>
-        <translation type="vanished">Papan tik</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Catatan&lt;/span&gt;: Jika Anda menggunakan sebuah &lt;span style=&quot; font-weight:600;&quot;&gt;metode masukkan&lt;/span&gt;, seperti IBus, uim, fcitx, atau gcin, pengaturan disini &lt;span style=&quot; font-weight:600;&quot;&gt;mungkin tidak bekerja&lt;/span&gt; karena mereka ditimpa oleh metode input.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
 </context>
 <context>
@@ -209,106 +135,106 @@
     <message>
         <location filename="../mouseconfig.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>Formulir</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="23"/>
         <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;b&gt;Tetikus&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="30"/>
         <source>Motion</source>
-        <translation type="unfinished">Gerakan</translation>
+        <translation>Gerakan</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="36"/>
         <source>High</source>
-        <translation type="unfinished">Tinggi</translation>
+        <translation>Tinggi</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="43"/>
         <source>Fast</source>
-        <translation type="unfinished">Cepat</translation>
+        <translation>Cepat</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="50"/>
         <source>Sensitivity:</source>
-        <translation type="unfinished">Sensitivitas:</translation>
+        <translation>Sensitivitas:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="57"/>
         <source>Low</source>
-        <translation type="unfinished">Rendah</translation>
+        <translation>Rendah</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="83"/>
         <source>Acceleration:</source>
-        <translation type="unfinished">Akselerasi:</translation>
+        <translation>Akselerasi:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="109"/>
         <source>Slow</source>
-        <translation type="unfinished">Lambat</translation>
+        <translation>Lambat</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="116"/>
         <location filename="../mouseconfig.ui" line="123"/>
         <source>0</source>
-        <translation type="unfinished">0</translation>
+        <translation>0</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="133"/>
         <source>Double click interval:</source>
-        <translation type="unfinished"></translation>
+        <translation>Interval klik ganda:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="140"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="150"/>
         <source>Wheel scroll lines:</source>
-        <translation type="unfinished"></translation>
+        <translation>Baris gulir roda:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="160"/>
         <source>Left handed (Swap left and right mouse buttons)</source>
-        <translation type="unfinished">Kidal (Tukar tombol tetikus kiri dan kanan)</translation>
+        <translation>Kidal (Tukar tombol tetikus kiri dan kanan)</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="167"/>
         <source>Single click to activate items</source>
-        <translation type="unfinished"></translation>
+        <translation>Klik tunggal untuk mengaktifkan item</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../lxqt-config-input.cpp" line="34"/>
-        <source>Keyboard and Mouse Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqt-config-input.cpp" line="39"/>
-        <source>Mouse</source>
-        <translation type="unfinished">Tetikus</translation>
-    </message>
-    <message>
-        <location filename="../lxqt-config-input.cpp" line="44"/>
-        <source>Cursor</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqt-config-input.cpp" line="47"/>
-        <source>Keyboard</source>
-        <translation type="unfinished">Papan tik</translation>
-    </message>
     <message>
         <location filename="../lxqt-config-input.cpp" line="51"/>
+        <source>Keyboard and Mouse Settings</source>
+        <translation>Pengaturan Papan Tik dan Tetikus</translation>
+    </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="56"/>
+        <source>Mouse</source>
+        <translation>Tetikus</translation>
+    </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="61"/>
+        <source>Cursor</source>
+        <translation>Kursor</translation>
+    </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="64"/>
+        <source>Keyboard</source>
+        <translation>Papan tik</translation>
+    </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="68"/>
         <source>Keyboard Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Tata Letak Papan Tik</translation>
     </message>
 </context>
 <context>
@@ -316,17 +242,17 @@
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
         <source>Select a keyboard layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Pilih tata letak papan tik</translation>
     </message>
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
         <source>Keyboard layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Tata letak papan tik</translation>
     </message>
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
         <source>Variant</source>
-        <translation type="unfinished"></translation>
+        <translation>Varian</translation>
     </message>
 </context>
 </TS>
