@@ -6,7 +6,7 @@
     <message>
         <location filename="../keyboardconfig.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="20"/>
@@ -26,7 +26,7 @@
     <message>
         <location filename="../keyboardconfig.ui" line="41"/>
         <source> ms</source>
-        <translation>ms</translation>
+        <translation> ms</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="51"/>
@@ -58,7 +58,7 @@
     <message>
         <location filename="../keyboardconfig.ui" line="129"/>
         <source>Type in the following box to test your keyboard settings</source>
-        <translation>Zacznij pisać w okienku, aby przetestować ustawienia swojej klawiatury</translation>
+        <translation>Użyj poniższego pola, aby przetestować ustawienia swojej klawiatury</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="150"/>
@@ -66,6 +66,11 @@
         <source>0</source>
         <translation>0</translation>
     </message>
+    <message>
+        <location filename="../keyboardconfig.ui" line="167"/>
+        <source>Turn on NumLock after login</source>
+        <translation>Włącz Num Lock po zalogowaniu</translation>
+    </message>
 </context>
 <context>
     <name>KeyboardLayoutConfig</name>
@@ -96,13 +101,13 @@
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="77"/>
-        <source>up</source>
-        <translation>do góry</translation>
+        <source>Up</source>
+        <translation>W górę</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="84"/>
-        <source>down</source>
-        <translation>w dół</translation>
+        <source>Down</source>
+        <translation>W dół</translation>
     </message>
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="108"/>
@@ -125,91 +130,12 @@
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Notka&lt;/span&gt;: Jeśli używasz &lt;span style=&quot; font-weight:600;&quot;&gt;metod wejścia&lt;/span&gt;, jak IBus, uim, fcitx, lub gcin, te ustawienia &lt;span style=&quot; font-weight:600;&quot;&gt;mogą nie działać&lt;/span&gt; ponieważ będą nadpisywane przez ustawienia tamtych metod.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
 </context>
-<context>
-    <name>MainDialog</name>
-    <message>
-        <source>Input Device Preferences</source>
-        <translation type="vanished">Preferencje urządzeń wejściowych</translation>
-    </message>
-    <message>
-        <source>Motion</source>
-        <translation type="vanished">Ruch</translation>
-    </message>
-    <message>
-        <source>High</source>
-        <translation type="vanished">Wysoka</translation>
-    </message>
-    <message>
-        <source>Fast</source>
-        <translation type="vanished">Szybkie</translation>
-    </message>
-    <message>
-        <source>Sensitivity:</source>
-        <translation type="vanished">Czułość:</translation>
-    </message>
-    <message>
-        <source>Low</source>
-        <translation type="vanished">Niska</translation>
-    </message>
-    <message>
-        <source>Acceleration:</source>
-        <translation type="vanished">Przyspieszenie:</translation>
-    </message>
-    <message>
-        <source>Slow</source>
-        <translation type="vanished">Wolne</translation>
-    </message>
-    <message>
-        <source>0</source>
-        <translation type="vanished">0</translation>
-    </message>
-    <message>
-        <source>Left handed (Swap left and right mouse buttons)</source>
-        <translation type="vanished">Leworęczna (Zamiana lewego i prawego przycisku myszy)</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation type="vanished">Mysz</translation>
-    </message>
-    <message>
-        <source>Character Repeat</source>
-        <translation type="vanished">Powtórzenia znaków</translation>
-    </message>
-    <message>
-        <source>Long</source>
-        <translation type="vanished">Długie</translation>
-    </message>
-    <message>
-        <source>Repeat delay:</source>
-        <translation type="vanished">Opóźnienie powtórki:</translation>
-    </message>
-    <message>
-        <source>Short</source>
-        <translation type="vanished">Krótkie</translation>
-    </message>
-    <message>
-        <source>Repeat interval:</source>
-        <translation type="vanished">Częstotliwość powtarzania:</translation>
-    </message>
-    <message>
-        <source>Type in the following box to test your keyboard settings</source>
-        <translation type="vanished">Zacznij pisać w okienku, aby przetestować ustawienia swojej klawiatury</translation>
-    </message>
-    <message>
-        <source>Beep when there is an error of keyboard input</source>
-        <translation type="vanished">Brzęczyk, gdy wystąpi błąd podczas wprowadzania z klawiatury</translation>
-    </message>
-    <message>
-        <source>Keyboard</source>
-        <translation type="vanished">Klawiatura</translation>
-    </message>
-</context>
 <context>
     <name>MouseConfig</name>
     <message>
         <location filename="../mouseconfig.ui" line="14"/>
         <source>Form</source>
-        <translation type="unfinished"></translation>
+        <translation>Formularz</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="23"/>
@@ -270,7 +196,7 @@
     <message>
         <location filename="../mouseconfig.ui" line="150"/>
         <source>Wheel scroll lines:</source>
-        <translation>Przwijanie kółkiem (linie):</translation>
+        <translation>Przewijanie kółkiem (linie):</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="160"/>
@@ -280,33 +206,33 @@
     <message>
         <location filename="../mouseconfig.ui" line="167"/>
         <source>Single click to activate items</source>
-        <translation>Pojedyńcze kliknięcie wyzwala akcję</translation>
+        <translation>Pojedyncze kliknięcie aktywuje akcje</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="34"/>
+        <location filename="../lxqt-config-input.cpp" line="51"/>
         <source>Keyboard and Mouse Settings</source>
         <translation>Ustawienia myszy i klawiatury</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="39"/>
+        <location filename="../lxqt-config-input.cpp" line="56"/>
         <source>Mouse</source>
         <translation>Mysz</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="44"/>
+        <location filename="../lxqt-config-input.cpp" line="61"/>
         <source>Cursor</source>
         <translation>Kursor</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="47"/>
+        <location filename="../lxqt-config-input.cpp" line="64"/>
         <source>Keyboard</source>
         <translation>Klawiatura</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="51"/>
+        <location filename="../lxqt-config-input.cpp" line="68"/>
         <source>Keyboard Layout</source>
         <translation>Układ klawiatury</translation>
     </message>
