@@ -21,7 +21,7 @@
     <message>
         <location filename="../keyboardconfig.ui" line="34"/>
         <source>Beep when there is an error of keyboard input</source>
-        <translation>Reproduzir um som se ocorrer um erro de teclado</translation>
+        <translation>Sinalizar se ocorrer um erro com o teclado</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="41"/>
@@ -58,7 +58,7 @@
     <message>
         <location filename="../keyboardconfig.ui" line="129"/>
         <source>Type in the following box to test your keyboard settings</source>
-        <translation>Digite algo na caixa abaixo para testar o teclado</translation>
+        <translation>Escreva algo na caixa abaixo para testar as definições</translation>
     </message>
     <message>
         <location filename="../keyboardconfig.ui" line="150"/>
@@ -127,7 +127,7 @@
     <message>
         <location filename="../keyboardlayoutconfig.ui" line="141"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nota&lt;/span&gt;: se estiver a utilizar um &lt;span style=&quot; font-weight:600;&quot;&gt;método de introdução&lt;/span&gt;, tal como IBus, uim, fcitx ou gcin, as alterações aqui efetuadas &lt;span style=&quot; font-weight:600;&quot;&gt;poderão não funcionar&lt;/span&gt;, uma vez que serão substituídas pelos métodos de introdução utilizados.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nota&lt;/span&gt;: se estiver a utilizar um &lt;span style=&quot; font-weight:600;&quot;&gt;método de entrada&lt;/span&gt;, tal como IBus, uim, fcitx ou gcin, as definições &lt;span style=&quot; font-weight:600;&quot;&gt;poderão não funcionar&lt;/span&gt;porque elas serão substituídas pelos métodos de entrada.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
 </context>
 <context>
@@ -165,7 +165,7 @@
     <message>
         <location filename="../mouseconfig.ui" line="57"/>
         <source>Low</source>
-        <translation>Baixa</translation>
+        <translation>Baixo</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="83"/>
@@ -196,17 +196,17 @@
     <message>
         <location filename="../mouseconfig.ui" line="150"/>
         <source>Wheel scroll lines:</source>
-        <translation>Roda do rato desloca:</translation>
+        <translation>Deslocação com a roda:</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="160"/>
         <source>Left handed (Swap left and right mouse buttons)</source>
-        <translation>Canhoto (inverter botões do rato)</translation>
+        <translation>Esquerdino (trocar botões do rato)</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="167"/>
         <source>Single click to activate items</source>
-        <translation>Ativar itens com um clique</translation>
+        <translation>Um clique para ativar itens</translation>
     </message>
 </context>
 <context>
@@ -214,7 +214,7 @@
     <message>
         <location filename="../lxqt-config-input.cpp" line="51"/>
         <source>Keyboard and Mouse Settings</source>
-        <translation>Definições do teclado e do rato</translation>
+        <translation>Definições de teclado e de rato</translation>
     </message>
     <message>
         <location filename="../lxqt-config-input.cpp" line="56"/>
@@ -242,7 +242,7 @@
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
         <source>Select a keyboard layout</source>
-        <translation>Selecione uma disposição</translation>
+        <translation>Selecione uma disposição do teclado</translation>
     </message>
     <message>
         <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
