@@ -82,21 +82,27 @@ LocaleConfig::~LocaleConfig()
 
 bool countryLessThan(const QLocale & c1, const QLocale & c2)
 {
-    return QString::localeAwareCompare(c1.nativeCountryName(), c2.nativeCountryName()) < 0;
+    // get the strings as in addLocaleToCombo() -> clabel
+    return QString::localeAwareCompare(!c1.nativeCountryName().isEmpty()
+                                           ? c1.nativeCountryName()
+                                           : c1.countryToString(c1.country()),
+                                       !c2.nativeCountryName().isEmpty()
+                                           ? c2.nativeCountryName()
+                                           : c2.countryToString(c2.country())) < 0;
 }
 
 void LocaleConfig::load()
 {
     QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
     qSort(allLocales.begin(), allLocales.end(), countryLessThan);
-    foreach(QComboBox * combo, m_combos)
+    for(QComboBox * combo : qAsConst(m_combos))
     {
         initCombo(combo, allLocales);
     }
 
     readConfig();
 
-    foreach(QComboBox * combo, m_combos)
+    for(QComboBox * combo : qAsConst(m_combos))
     {
         connectCombo(combo);
     }
@@ -119,7 +125,7 @@ void LocaleConfig::initCombo(QComboBox *combo, const QList<QLocale> & allLocales
     const QString clabel = tr("No change");
     combo->setInsertPolicy(QComboBox::InsertAlphabetically);
     combo->addItem(clabel, QString());
-    foreach(const QLocale & l, allLocales)
+    for(const QLocale & l : qAsConst(allLocales))
     {
         addLocaleToCombo(combo, l);
     }
