@@ -20,6 +20,9 @@
 
 #define TIMER_DURATION 10
 
+#include <QIcon>
+#include <QStyle>
+
 #include "timeoutdialog.h"
 
 TimeoutDialog::TimeoutDialog(QWidget* parent, Qt::WindowFlags f) :
